#
# spec file for package python-Lektor
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
%define modname Lektor
Name:           python-Lektor
Version:        3.3.7
Release:        1.7
Summary:        A static content management system
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/lektor/lektor/
Source:         https://files.pythonhosted.org/packages/source/L/%{modname}/%{modname}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM new_version_of_mistune.patch gh#lektor/lektor#944 mcepl@suse.com
# Make package working with mistune 2.*
Patch0:         new_version_of_mistune.patch
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Babel
Requires:       python-ExifRead
Requires:       python-Flask
Requires:       python-Jinja2 >= 2.11
Requires:       python-click >= 6.0
Requires:       python-filetype >= 1.0.7
Requires:       python-inifile
Requires:       python-mistune >= 0.7.0
Requires:       python-python-slugify
Requires:       python-requests
Requires:       python-setuptools
Requires:       python-watchdog
Requires(post): update-alternatives
Requires(postun):update-alternatives
Suggests:       git-core
Suggests:       python-pip
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Babel}
BuildRequires:  %{python_module ExifRead}
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module Jinja2 >= 2.11}
BuildRequires:  %{python_module click >= 6.0}
BuildRequires:  %{python_module cryptography >= 1.3.4}
BuildRequires:  %{python_module filetype >= 1.0.7}
BuildRequires:  %{python_module inifile}
BuildRequires:  %{python_module mistune >= 0.7.0}
BuildRequires:  %{python_module pyOpenSSL >= 0.14}
BuildRequires:  %{python_module pylint}
BuildRequires:  %{python_module pytest-click}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-slugify}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module watchdog}
BuildRequires:  git-core
%if %{with python2}
BuildRequires:  python2-functools32
%endif
# /SECTION
%ifpython2
Requires:       python-functools32
%endif
%python_subpackages

%description
A static content management system for building complex websites out
of flat files for people who do not want to make a compromise between
a CMS and a static blog engine.

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/lektor
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF8
rm -v tests/test_markdown.py
# Test suite expects a git repo
git init -b master
%pytest -k 'not (requiresinternet or test_resolve_artifact)'

%post
%python_install_alternative lektor

%postun
%python_uninstall_alternative lektor

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/lektor
%{python_sitelib}/*

%changelog
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.3.7
  * Bugs
    Dev Server
    Remove frontend javascript rebuild machinery altogether. Since the frontend source code is not included in distributed Lektor
    wheels this was breaking LEKTOR_DEV functionality for all but those running Lektor from git. (#1072)
* Wed Jul 27 2022 Matej Cepl <mcepl@suse.com>
- Update to 3.3.6:
  - Spurious edit page scrolling when typing in textareas is now
    (hopefully) fixed.
  - Fixed the edit hotkey (<ctl>-e or <meta>-e on a Mac) so that
    it works again.
  - The save hotkey (<ctl>-s or equivalent) in the edit view now
    always switches to the preview view.
* Fri Jul 22 2022 Matej Cepl <mcepl@suse.com>
- Update to 3.3.5:
  - Backport #1044. Fixes 404 from admin server for /admin.
  - Backport #1033. Fixes TypeError from click==8.1.3.
  - Back-port #1019: fixes for werkzeug 2.1.0.
- Update to 3.3.2:
  - Enabled the Jinja debug extension when the LEKTOR_DEV env var
    is set to 1 and lektor server is used. (#984)
  - The wording in the LICENSE file was standardized to that of
    the current BSD 3-Clause License. (#972)
  - Fix overzealous HTML-entity escaping of link and image
    attributes. (#989)
  - Fix a bug in make_editor_session when editing non-existant
    pages with a non-primary alt. (#964)
  - Fix the ability to add an initial flowblock to a
    page. (Broken in 3.3.1.)
  - Refactor API views to move business logic back into the Tree
    adapter (#967). This fixes #962.
  - Changed the structure of the URLs used by the GUI single-page
    app (#976). This fixes problems with the "edit" pencil when
    using alternatives (#975), and issues when page ids include
    colons (#610).
  - Other React refactors and fixes (#988).
  - Fix Attachment.url_path when alternatives are in use. There
    is only one copy of each attachment emitted — the url_path
    should always be that corresponding to the primary
    alternative. (#958)
  - Pad.get, if not passed an explicit value for the alt
    parameter, now returns the record for the primary alternative
    rather than the fallback record. Similarly, Pad.root now
    returns the root record for the primary alternative. (#958,
    [#965])
  - Fix for uncaught OSError(error=EINVAL) on Windows when
    Pad.get was called with a path containing characters which
    are not allowed in Windows filenames (e.g. <>*?|\/":).
  - Pages now record a build dependency on their datamodel .ini
    file.
  - Fix sqlite version detection so that we use "without rowid"
    optimization with current versions of sqlite. (#1002)
  - When running lektor dev new-theme: fix check for ability to
    create symlinks under Windows. (#996)
  - Fix rsync publisher when deletion enabled on macOS. (#946,
    [#954])
  - Fix for test failures when git is not installed. (#998,
    [#1000])
  - Cleaned up EditorSession to split mapping methods (for
    access to record data) to a separate class, now available as
    EditorSession.data. (#969)
  - Cleaned up and moved our pylint and coverage configuration to
    pyproject.toml. (#990, #991)
  - Move frontend source from lektor/admin/static/
    to frontend/. Compiled frontend code moved from
    lektor/admin/static/gen/ to 'lektor/admin/static/`. (#1003)
  - Omit example subdirectory, frontend source code,
    developer-centric config files, as well as other assorted
    cruft from sdist. (#986)
- Update to 3.3.1:
  - Fixed an import cycle which caused in ImportError if
    lektor.types was imported before lektor.environemnt. #974
  - Disuse deprecated Thread.setDaemon(). #979
  - Fix spastic scroll behavior when editing flow elements. #640
  - Fix admin GUI when page contains an unknown flowblock
    type. #968
  - Fix admin GUI layout on mobile devices. #981
  - Increased timeout in test_watcher.IterateInThread to prevent
    random spurious failures during CI testing.
  - Fix tests/test_prev_next_sibling.py so as to allow running
    multiple test runs in parallel.
  - Use per-testenv coverage files to prevent contention when
    running tox --parallel.
  - Mark tests that require a working internet connections with
    pytest mark requiresinternet. #983
  - Finish rewriting React class-based components to
    function-based components. #977
  - Finish adding types for all API endpoints. #980
  - Remove disused event-source polyfill.
- Remove upstreamed patch skip-network-tests.patch.
* Thu Jan  6 2022 Matej Cepl <mcepl@suse.com>
- We don't have to skip failing test due to new version of
  mistune.
* Wed Jan  5 2022 Matej Cepl <mcepl@suse.com>
- Upgrade to 3.3.0:
  - This release drops support for versions of Python before
    3.6. In particular, Python 2.7 is no longer supported.
  - Quite a few bugs have been fixed since the previous release.
  - The Admin UI has seen a major refactor and various
    performance optimisations. It has been rewritten in
    Typescript, and updated to use v5 of the Bootstrap CSS
    framework.
- Remove unnecessary patches:
  - more_recent_werkzeug.patch
  - werkzeug_rename.patch
- Added patches making things working:
  - new_version_of_mistune.patch (gh#lektor/lektor#944) make the
    package work with mistune 2.*
  - skip-network-tests.patch (gh#lektor/lektor#982) we build in
    the network isolated environment, we need to make tests which
    need it
* Wed Dec  8 2021 pgajdos@suse.com
- do not require pytest-runner for build, not required
* Thu Aug  5 2021 Matej Cepl <mcepl@suse.com>
- Update to 3.2.0:
  - Fix off-by-one error in pagination's iter_pages in the
    interpretation of the right_current argument, and adding an
    appropriate trailing None for some uses.
  - Add support for setting an output_path in the project file.
  - Replaced the slugify backend to handle unicode more effectively.
    This should mean greater language support, but it may produce
    slightly different results in some cases.
  - Several modernization and performance improvements to the admin UI
  - Improved speed of source info updates.
  - Set colorspace to sRGB for thumbnails.
  - Now stripping profiles and comments from thumbnails.
  - Added support for deleting and excluding files for the rsync
    deployment publisher.
  - Improved speed of flow rendering in the admin UI.
  - Bugfix to correctly calculate relative urls from slugs that contain
    dots.
  - Bugfix to allow negative integers in integer fields in the admin UI.
  - Improved image-heavy build speeds by reducing the amount of data
    extracted from EXIFs.
  - Added the ability to collapse flow elements in the admin UI.
  - Now extra_flags is passed to all plugin events.
  - Extra flags can now be passed to the clean and dev shell CLI
    commands.
  - Bugfix where lektor plugins reinstall triggered on_setup_env instead
    of just reinstalling plugins.
  - Added the ability to generate video thumbnails with ffmpeg.
  - Added mode and upscale thumbnail arguments, changing the preferred
    crop method to using mode. mode can be crop, fit, or stretch.
    upscale=False can now prevent upscaling.
  - Added a new CLI command lektor dev new-theme.
  - Made admin use full UTF-8 version of RobotoSlab. Fixes missing
    glyphs for some languages
  - Bumped minimum Jinja2 version to 2.11
  - Bumped filetype dependency to 1.0.7 because of API changes
  - Relative urls are now as short as possible.
  - Automatically include setup.cfg configured for universal wheels when
    creating plugins
- Add two patches to make Lektor work with the modern werkzeug:
  - more_recent_werkzeug.patch
  - werkzeug_rename.patch
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Mon Apr 15 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
* Sat Apr 13 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Re-enable Python 2; tidy spec
- Update to v3.1.3
* Sun Jun 24 2018 arun@gmx.de
- Convert to single spec, with Python 2 disabled
- Update to v3.1.1
* Tue Jun  7 2016 sbahling@suse.com
- Initial package. Version 2.3.
